package org.syzygy.mp3.server;

import java.io.*;
import java.net.*;
import java.net.MalformedURLException; 
import javax.xml.rpc.ServiceException; 
import java.rmi.RemoteException;
import java.util.Iterator;
import java.util.List;
import java.util.ArrayList;
import org.syzygy.util.CommandLine;
import com.amazon.soap.axis.*;

public class FetchCoverArt
{
    public static final int SMALL = 0x01;
    public static final int MEDIUM = 0x02;
    public static final int LARGE = 0x04;
    public static final int ALL = SMALL + MEDIUM + LARGE;
    
    public static void main(String[] args)
        throws MalformedURLException, ServiceException, RemoteException
    {
        CommandLine opts = new CommandLine(args);
        FetchCoverArt fetcher = new FetchCoverArt();
        if (opts.contains("-id"))
            fetcher.setID(opts.valueOf("-id"));
        if (opts.contains("-small"))
            fetcher.setWhich(SMALL);
        else if (opts.contains("-medium"))
            fetcher.setWhich(MEDIUM);
        else if (opts.contains("-large"))
            fetcher.setWhich(LARGE);
        
        int arg = opts.argumentStart();
        List results = fetcher.fetchCovers(args[arg], args[arg+1]);
        for (Iterator i = results.iterator(); i.hasNext(); )
            System.out.println((String)i.next());
    }

    public void setWhich(int which)
    {
        this.which = which;
    }

    public void setID(String id)
    {
        this.id = id;
    }

    private String id = "";
    private int which = ALL;
        
    public List fetchCovers(String artist, String album)
        throws MalformedURLException, ServiceException, RemoteException
    {
        AWSECommerceServiceLocator service = new AWSECommerceServiceLocator();
        AWSECommerceServicePortType port = service.getAWSECommerceServicePort();
	ItemSearchRequest request = new ItemSearchRequest();
        request.setArtist(artist);
	request.setTitle(album);
	request.setSearchIndex("Music");
	request.setResponseGroup(new String[] { "Medium" });
	ItemSearchRequest[] requests = new ItemSearchRequest[1];
	requests[0] = request;
	ItemSearch search = new ItemSearch();
	search.setRequest(requests);
	search.setAWSAccessKeyId(id);

        album = StringUtil.munge(album);
        List<String> results = new ArrayList<String>();

	ItemSearchResponse info = port.itemSearch(search);
	Items[] items = info.getItems();

	for (int ii = 0; ii < items.length; ii++) {
	    Item[] item = items[ii].getItem();
	    for (int i = 0; i < item.length; i++) {
		Item it = item[i];
		String title = StringUtil.munge(it.getItemAttributes().getTitle());

		if (title.startsWith(album) || album.startsWith(title)) {
		    if ((which & LARGE) != 0 && it.getLargeImage() != null)
			results.add(it.getLargeImage().getURL());
		    if ((which & MEDIUM) != 0 && it.getMediumImage() != null)
			results.add(it.getMediumImage().getURL());
		    if ((which & SMALL) != 0 && it.getSmallImage() != null)
			results.add(it.getSmallImage().getURL());
		    return results;
		}
	    }
	}
        return results;
    }

    public static void downloadCover(File dir, String u, String name)
        throws IOException
    {
        String suffix = "";
        int s = u.lastIndexOf(".");
        if (s != -1)
            suffix = u.substring(s).toLowerCase();
            
        File file = new File(dir, name + suffix);
        OutputStream output = new FileOutputStream(file);
        NetUtil.download(new URL(u), output);
        output.close();
    }
}
